from shiftregister.importer.models import *

night_shift_query = Q(start_at__hour__gte=21) | Q(start_at__hour__lte=10)


class TeamMember(models.Model):
    name = models.CharField(max_length=100)
    fallback_shifts = models.ManyToManyField(Shift, through="FallbackAssignment")

    def assign_random_shifts(self):
        events_bucket_1 = Event.objects.filter(
            ~night_shift_query, deleted=False, calendar__needs_fallback=True
        )
        events_bucket_2 = Event.objects.filter(
            night_shift_query, deleted=False, calendar__needs_fallback=True
        )
        self._assign_from_bucket(events_bucket_1)
        self._assign_from_bucket(events_bucket_2)

    def _assign_from_bucket(self, bucket):
        quota = global_preferences["helper__fallback_quota"]
        number_of_team_members = TeamMember.objects.count()
        max_shifts_per_member = bucket.count() / (number_of_team_members * quota)

        assigned_shifts = self.fallback_shifts.filter(night_shift_query)

        # for events in events:
        # self.fallback_shifts.add(events)

    def __str__(self):
        return f"{self.name}"


class FallbackAssignment(models.Model):
    shift = models.ForeignKey(Shift, on_delete=models.CASCADE)
    team_member = models.ForeignKey(TeamMember, on_delete=models.CASCADE)

    def __str__(self):
        return f"{self.shift} {self.team_member.name}"
